@@ -31,9 +31,9 @@ import subprocess
 import traceback
 import errno
 import time
-import pipes
 import socket
 import shutil
+import shlex
 
 import adtlog
 
@@ -529,7 +529,7 @@ def copyupdown_internal(wh, sd, upp):
 
     deststdout = devnull_read
     srcstdin = devnull_read
-    remfileq = pipes.quote(sd[iremote])
+    remfileq = shlex.quote(sd[iremote])
     if not dirsp:
         rune = 'cat %s%s' % ('><'[upp], remfileq)
         if upp:
