@@ -24,9 +24,9 @@ import os
 import sys
 import errno
 import time
-import pipes
 import traceback
 import re
+import shlex
 import signal
 import subprocess
 import tempfile
@@ -113,7 +113,7 @@ class Testbed:
 
         # log command line invocation for the log
         adtlog.info('host %s; command line: %s' % (
-            os.uname()[1], ' '.join([pipes.quote(w) for w in sys.argv])))
+            os.uname()[1], ' '.join([shlex.quote(w) for w in sys.argv])))
 
         self.sp = subprocess.Popen(self.vserver_argv,
                                    stdin=subprocess.PIPE,
