@@ -254,7 +254,8 @@ for details.'''
                          '{ [ "${O%404*Not Found*}" = "$O" ] || exit 100; sleep 15; apt-get update; }'''
                          ' || { sleep 60; apt-get update; } || false)'
                          ' && $(which eatmydata || true) apt-get dist-upgrade -y -o '
-                         'Dpkg::Options::="--force-confnew"',
+                         'Dpkg::Options::="--force-confnew"'
+                         ' && $(which eatmydata || true) apt-get --purge autoremove -y',
                          help='Run apt update/dist-upgrade before the tests')
     g_setup.add_argument('--setup-commands-boot', metavar='COMMANDS_OR_PATH',
                          action='append', default=[],
