@@ -477,7 +477,7 @@ def _check_architecture(name, testbed_arch, architectures):
             any_negative = True
             if _matches_architecture(testbed_arch, arch[1:]):
                 raise Unsupported(name, "Test declares architecture as not " +
-                                  "supported: %s" % arch)
+                                  "supported: %s" % testbed_arch)
         if arch[0] != "!":
             any_positive = True
 
@@ -494,7 +494,7 @@ def _check_architecture(name, testbed_arch, architectures):
         if not arch_matched:
             raise Unsupported(name, "Test lists explicitly supported " +
                               "architectures, but the current architecture " +
-                              "%s isn't listed." % arch)
+                              "%s isn't listed." % testbed_arch)
 
 
 def parse_debian_source(srcdir, testbed_caps, testbed_arch, control_path=None,
